@@ -1,15 +1,15 @@
 
 module Config
 
-  RUBY_VERSION == "1.6.4" or
-    raise "ruby lib version (1.6.4) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.6.5" or
+    raise "ruby lib version (1.6.5) doesn't match executable version (#{RUBY_VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-mingw32\Z', '')
-  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.4"
+  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.5"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -35,7 +35,7 @@ module Config
   CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "4"
+  CONFIG["TEENY"] = "5"
   CONFIG["host"] = "i686-pc-cygwin"
   CONFIG["host_alias"] = "i686-pc-cygwin"
   CONFIG["host_cpu"] = "i686"
@@ -76,7 +76,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.4/mobj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.5/mobj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -bmingw --export-all -s"
   CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
@@ -99,7 +99,7 @@ module Config
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/ruby-1.6.4/mobj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.5/mobj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
